@@ -27,7 +27,7 @@
 #define R__HAS_VC    /**/
 #define R__HAS_VDT    /**/
 #undef R__HAS_VECCORE    /**/
-#define R__USE_CXXMODULES   /**/
+#undef R__USE_CXXMODULES   /**/
 #undef R__USE_LIBCXX    /**/
 #define R__HAS_STD_STRING_VIEW   /**/
 #undef R__HAS_STD_EXPERIMENTAL_STRING_VIEW   /**/
